@@ -127,6 +127,50 @@ def sp_vals(bit_width,signed):
     dataset = list(map(conv_func,dataset)) + [int(sqrt(abs(conv_func("0x8"+"".join(["0"]*int((bit_width/4)-1)))))*(-1 if signed else 1))] + [sqrt_min,sqrt_max]
     return dataset + [x - 1 if x>0 else 0 for x in dataset] + [x+1 for x in dataset]
 
+def bitmanip_dataset(bit_width,var_lst=["rs1_val","rs2_val"],signed=True):
+    '''
+    Functions creates coverpoints for bitmanip instructions with following patterns
+    0x3, 0xc, 0x5,0xa,0x6,0x9,0 each of the pattern exenteding for bit_width
+    for 32 bit
+    0x33333333,0xcccccccc,0x55555555, 0xaaaaaaaaa,0x66666666,0x99999999
+    for 64 bit
+    0x3333333333333333,0xcccccccccccccccc,0x5555555555555555, 0xaaaaaaaaaaaaaaaaa,
+    0x6666666666666666,0x9999999999999999
+     - +1 and -1 variants of the above pattern
+
+
+     :param bit_width: Integer defining the size of the input
+     :param sign: Boolen value specifying whether the dataset should be interpreted as signed numbers or not.
+     :type sign: bool
+     :type bit_width: int
+     :return: dictionary of coverpoints
+    '''
+
+    datasets = []
+    coverpoints = []
+    if signed:
+        conv_func = lambda x: twos(x,bit_width)
+    else:
+        conv_func = lambda x: (int(x,16) if '0x' in x else int(x,2)) if isinstance(x,str) else x
+# dataset for 0x5, 0xa, 0x3, 0xc, 0x6, 0x9 patterns
+    dataset = ["0x"+"".join(["5"]*int(bit_width/4)), "0x"+"".join(["a"]*int(bit_width/4)), "0x"+"".join(["3"]*int(bit_width/4)), "0x"+"".join(["c"]*int(bit_width/4)),"0x"+"".join(["6"]*int(bit_width/4)),"0x"+"".join(["9"]*int(bit_width/4))]
+    dataset = list(map(conv_func,dataset))
+
+# dataset0 is  for 0,1 and 0xf pattern. 0xf pattern is added instead of -1 so that code for checking coverpoints in coverage.py
+# is kept simple.
+
+    dataset0 = [0,1,"0x"+"".join(["f"]*int(bit_width/4))]
+    dataset0 = list(map(conv_func,dataset0))
+    dataset = dataset +  [x - 1 for x in dataset] + [x+1 for x in dataset] + dataset0
+    for var in var_lst:
+        datasets.append(dataset)
+    dataset = itertools.product(*datasets)
+    for entry in dataset:
+        coverpoints.append(' and '.join([var_lst[i]+"=="+str(entry[i]) for i in range(len(var_lst))]))
+    return [(coverpoint,"Bitmanip Dataset") for coverpoint in coverpoints]
+
+
+
 def sp_dataset(bit_width,var_lst=["rs1_val","rs2_val"],signed=True):
     coverpoints = []
     datasets = []
