@@ -1,7 +1,10 @@
 # See LICENSE.incore for details
 """Console script for riscv_isac."""
 
+import os
 import click
+import shutil
+from git import Repo
 
 from riscv_isac.isac import isac
 from riscv_isac.__init__ import __version__
@@ -74,7 +77,8 @@ def cli(verbose):
 @click.option(
         '--output-file','-o',
         type=click.Path(writable=True,resolve_path=True),
-        help="Coverage Group File"
+        help="Coverage Group File",
+        required=True
     )
 @click.option(
         '--test-label',
@@ -171,3 +175,49 @@ def normalize(cgf_file,output_file,xlen):
         utils.dump_yaml(expand_cgf(cgf_file,int(xlen)),outfile)
 
 
+
+@cli.command(help = 'Setup the plugin which uses the information from RISCV Opcodes repository to decode.')
+@click.option('--url',
+                type = str,
+                default='https://github.com/riscv/riscv-opcodes',
+                required=False,
+                help='URL to the riscv-opcodes repo')
+@click.option('--branch',type=str,default='master')
+@click.option('--plugin-path',
+                type=click.Path(resolve_path=True,writable=True),
+                help="Target folder to setup the plugin files in. [./]",
+                default="./rvop_decoder")
+@click.option("--rvop-path",
+                type=click.Path(resolve_path=True,writable=True),
+                help="Path to RVOpcodes directory.")
+# Clone repo
+def setup(url,branch, plugin_path, rvop_path):
+    # path = os.getcwd() + '/plugins/riscv_opcodes/'
+    if not os.path.exists(plugin_path):
+        logger.debug("Creating directory: "+str(plugin_path))
+        os.mkdir(plugin_path)
+    target_dir = os.path.join(plugin_path,"riscv_opcodes/")
+    repo = None
+    if rvop_path is not None:
+        if not os.path.exists(rvop_path):
+            logger.warning("RISCV Opcodes folder not found at: "+rvop_path)
+            clone = click.prompt("Do you wish to clone from git?",
+                        default='Y',type=click.Choice(['Y','n','y','N']),show_choices=True)
+            if clone == 'Y' or clone == 'y':
+                logger.debug("Cloning from Git.")
+                repo = Repo.clone_from(url, rvop_path)
+                repo.git.checkout(branch)
+            else:
+                logger.error("Exiting Setup.")
+                raise SystemExit
+        os.symlink(rvop_path,target_dir[:-1])
+    else:
+        logger.debug("Cloning from Git.")
+        repo = Repo.clone_from(url, target_dir)
+        repo.git.checkout(branch)
+    plugin_file = os.path.join(os.path.dirname(__file__), "data/rvopcodesdecoder.py")
+    constants_file = os.path.join(os.path.dirname(__file__), "data/constants.py")
+    logger.debug("Copying plugin files.")
+    shutil.copy(plugin_file,plugin_path)
+    shutil.copy(constants_file,plugin_path)
+
